% paper Mazenc-Prieur, 2010
% parabolic equation and strict Lyapunov function

clear all 
close all

disp('simulating the second example of [Mazenc Prieur, 2010]')
disp('two coupled parabolic equations with a linearity')

% cd('~cprieur/Documents/Travail/Recherche/Mazenc/Simulations/Example2')

% data
%
%Nx=100; % step of the spatial variable
%Nt=10000; % step of the time variable
Nx=40; % step of the spatial variable
Nt=1000; % step of the time variable
tf=10; % final time
t0=0; % initial time
delta=1; % size of the perturbations (it multiplies the perturb function
Nfig=0; % with 0, first figure that is used will be figure(1)

% discretizing the solution
% the perturbations are given by the perturbation function
% multiplied by delta
[u1,u2,x,t]=heatlinear(0,tf,Nx,Nt,delta);

%[u,err,x,t]=heat1(0,tf,Nx,Nt,delta,PerturbCut);

% check if the solution is infinite or not
if max(max([isinf(u1);isinf(u2);isnan(u1);isnan(u2)]))
    disp('numerical explosion')
    return
end

dx = 2*pi/(Nx-1);

% computing the Lyapunov function
V=lyapunov(u1,u2,dx);

Nfig=Nfig+1;figure(Nfig)
imagesc(t,x,u1);
title('solution u1 of the PDE')
colorbar
xlabel('t')
ylabel('x')
%print -depsc2 'solution.eps'

Nfig=Nfig+1;figure(Nfig)
imagesc(t,x,u2);
title('solution u2 of the PDE')
colorbar
xlabel('t')
ylabel('x')
%print -depsc2 'solution.eps'

Nfig=Nfig+1;figure(Nfig)
contourf(t,x,u1);
title('solution u1 of the PDE (contourf)')
colorbar
xlabel('t')
ylabel('x')


Nfig=Nfig+1;figure(Nfig)
contourf(t,x,u2);
title('solution u2 of the PDE (contourf)')
colorbar
xlabel('t')
ylabel('x')

Nfig=Nfig+1;figure(Nfig)
Nt1=floor(Nt/4); 
Nt2=floor(Nt/2); 
Nt3=floor(3*Nt/4);
plot(x,u1(:,1),x,u1(:,Nt1),x,u1(:,Nt2),x,u1(:,Nt3),x,u1(:,Nt))
xlabel('lenght');
ylabel('u1'); 
legend('t0','t=Tf /4 ','Tf/2','3Tf/4', 'Tf')
axis tight
%print -depsc2 'partial-solution.eps'

Nfig=Nfig+1;figure(Nfig)
plot(x,u2(:,1),x,u2(:,Nt1),x,u2(:,Nt2),x,u2(:,Nt3),x,u2(:,Nt))
xlabel('lenght');
ylabel('u2'); 
legend('t0','t=Tf /4 ','Tf/2','3Tf/4', 'Tf')
axis tight
%print -depsc2 'partial-solution.eps'

% stepfigx=floor(Nx/20);stepfigt1=floor(Nt/20);%stepfigt2=floor(NT/200);
% if min(stepfigx,stepfigt1)>0
%     Nfig=Nfig+1;figure(Nfig)
%     [x1,t1]=meshgrid(x(1:stepfigx:Nx),t(1:stepfigt1:Nt));
%     mesh(x1,t1,u1(1:stepfigx:Nx,1:stepfigt1:Nt));xlabel('t');ylabel('x');zlabel('u1');
%     % print -depsc2 '3d-solution.eps'
%     Nfig=Nfig+1;figure(Nfig)
%     mesh(x1,t1,u2(1:stepfigx:Nx,1:stepfigt1:Nt));xlabel('t');ylabel('x');zlabel('u2');
%     % print -depsc2 '3d-solution.eps'
% end
    
Nfig=Nfig+1;figure(Nfig)
[x1,t1]=meshgrid(x,t);
mesh(x1,t1,u1');xlabel('z');ylabel('t');zlabel('x_1');
view(62,24)
print -depsc2 'ex1-solution1.eps'
Nfig=Nfig+1;figure(Nfig)
mesh(x1,t1,u2');xlabel('z');ylabel('t');zlabel('x_2');
view(62,24)
print -depsc2 'ex2-solution2.eps'


Nfig=Nfig+1;figure(Nfig)
plot(t,V)
xlabel('t');
ylabel('$\overline{U}$','Interpreter','latex');
axis tight
print -depsc2 'lyapunov.eps'


